import Service from "../../service";
import Client from "../../client";
import { IRequest } from "../../typings/requestOptions";
import { PinChangeRequest } from "../../typings/balancePlatform/models";
import { PinChangeResponse } from "../../typings/balancePlatform/models";
import { PublicKeyResponse } from "../../typings/balancePlatform/models";
import { RevealPinRequest } from "../../typings/balancePlatform/models";
import { RevealPinResponse } from "../../typings/balancePlatform/models";
/**
 * API handler for ManageCardPINApi
 */
export declare class ManageCardPINApi extends Service {
    private readonly API_BASEPATH;
    private baseUrl;
    constructor(client: Client);
    /**
    * @summary Change a card PIN
    * @param pinChangeRequest {@link PinChangeRequest }
    * @param requestOptions {@link IRequest.Options }
    * @return {@link PinChangeResponse }
    */
    changeCardPin(pinChangeRequest: PinChangeRequest, requestOptions?: IRequest.Options): Promise<PinChangeResponse>;
    /**
    * @summary Get an RSA public key
    * @param requestOptions {@link IRequest.Options }
    * @param purpose {@link string } The purpose of the public key.  Possible values: **pinChange**, **pinReveal**, **panReveal**.  Default value: **pinReveal**.
    * @param format {@link string } The encoding format of public key.  Possible values: **jwk**, **pem**.  Default value: **pem**.
    * @return {@link PublicKeyResponse }
    */
    publicKey(purpose?: string, format?: string, requestOptions?: IRequest.Options): Promise<PublicKeyResponse>;
    /**
    * @summary Reveal a card PIN
    * @param revealPinRequest {@link RevealPinRequest }
    * @param requestOptions {@link IRequest.Options }
    * @return {@link RevealPinResponse }
    */
    revealCardPin(revealPinRequest: RevealPinRequest, requestOptions?: IRequest.Options): Promise<RevealPinResponse>;
}
