import Service from "../../service";
import Client from "../../client";
import { IRequest } from "../../typings/requestOptions";
import { OnboardingLink } from "../../typings/legalEntityManagement/models";
import { OnboardingLinkInfo } from "../../typings/legalEntityManagement/models";
import { OnboardingTheme } from "../../typings/legalEntityManagement/models";
import { OnboardingThemes } from "../../typings/legalEntityManagement/models";
/**
 * API handler for HostedOnboardingApi
 */
export declare class HostedOnboardingApi extends Service {
    private readonly API_BASEPATH;
    private baseUrl;
    constructor(client: Client);
    /**
    * @summary Get a link to an Adyen-hosted onboarding page
    * @param id {@link string } The unique identifier of the legal entity
    * @param onboardingLinkInfo {@link OnboardingLinkInfo }
    * @param requestOptions {@link IRequest.Options }
    * @return {@link OnboardingLink }
    */
    getLinkToAdyenhostedOnboardingPage(id: string, onboardingLinkInfo: OnboardingLinkInfo, requestOptions?: IRequest.Options): Promise<OnboardingLink>;
    /**
    * @summary Get an onboarding link theme
    * @param id {@link string } The unique identifier of the theme
    * @param requestOptions {@link IRequest.Options }
    * @return {@link OnboardingTheme }
    */
    getOnboardingLinkTheme(id: string, requestOptions?: IRequest.Options): Promise<OnboardingTheme>;
    /**
    * @summary Get a list of hosted onboarding page themes
    * @param requestOptions {@link IRequest.Options }
    * @return {@link OnboardingThemes }
    */
    listHostedOnboardingPageThemes(requestOptions?: IRequest.Options): Promise<OnboardingThemes>;
}
