import Service from "../../service";
import Client from "../../client";
import { IRequest } from "../../typings/requestOptions";
import { Logo } from "../../typings/management/models";
import { TerminalSettings } from "../../typings/management/models";
/**
 * API handler for TerminalSettingsCompanyLevelApi
 */
export declare class TerminalSettingsCompanyLevelApi extends Service {
    private readonly API_BASEPATH;
    private baseUrl;
    constructor(client: Client);
    /**
    * @summary Get the terminal logo
    * @param companyId {@link string } The unique identifier of the company account.
    * @param requestOptions {@link IRequest.Options }
    * @param model {@link string } (Required) The terminal model. Possible values: E355, VX675WIFIBT, VX680, VX690, VX700, VX820, M400, MX925, P400Plus, UX300, UX410, V200cPlus, V240mPlus, V400cPlus, V400m, e280, e285, e285p, S1E, S1EL, S1F2, S1L, S1U, S7T.
    * @return {@link Logo }
    */
    getTerminalLogo(companyId: string, model: string, requestOptions?: IRequest.Options): Promise<Logo>;
    /**
    * @summary Get terminal settings
    * @param companyId {@link string } The unique identifier of the company account.
    * @param requestOptions {@link IRequest.Options }
    * @return {@link TerminalSettings }
    */
    getTerminalSettings(companyId: string, requestOptions?: IRequest.Options): Promise<TerminalSettings>;
    /**
    * @summary Update the terminal logo
    * @param companyId {@link string } The unique identifier of the company account.
    * @param logo {@link Logo }
    * @param requestOptions {@link IRequest.Options }
    * @param model {@link string } (Required) The terminal model. Possible values: E355, VX675WIFIBT, VX680, VX690, VX700, VX820, M400, MX925, P400Plus, UX300, UX410, V200cPlus, V240mPlus, V400cPlus, V400m, e280, e285, e285p, S1E, S1EL, S1F2, S1L, S1U, S7T.
    * @return {@link Logo }
    */
    updateTerminalLogo(companyId: string, logo: Logo, model: string, requestOptions?: IRequest.Options): Promise<Logo>;
    /**
    * @summary Update terminal settings
    * @param companyId {@link string } The unique identifier of the company account.
    * @param terminalSettings {@link TerminalSettings }
    * @param requestOptions {@link IRequest.Options }
    * @return {@link TerminalSettings }
    */
    updateTerminalSettings(companyId: string, terminalSettings: TerminalSettings, requestOptions?: IRequest.Options): Promise<TerminalSettings>;
}
