import { acsWebhooks } from "..";
/**
 * Union type for all supported webhook requests.
 * Allows generic handling of configuration-related webhook events.
 */
export type GenericWebhook = acsWebhooks.AuthenticationNotificationRequest | acsWebhooks.RelayedAuthenticationRequest;
/**
 * Handler for processing AcsWebhooks.
 *
 * This class provides functionality to deserialize the payload of AcsWebhooks events.
 */
export declare class AcsWebhooksHandler {
    private readonly payload;
    constructor(jsonPayload: string);
    /**
     * This method checks the type of the webhook payload and returns the appropriate deserialized object.
     *
     * @returns A deserialized object of type GenericWebhook.
     * @throws Error if the type is not recognized.
     */
    getGenericWebhook(): GenericWebhook;
    /**
     * Deserialize the webhook payload into a AuthenticationNotificationRequest
     *
     * @returns Deserialized AuthenticationNotificationRequest object.
     */
    getAuthenticationNotificationRequest(): acsWebhooks.AuthenticationNotificationRequest;
    /**
     * Deserialize the webhook payload into a RelayedAuthenticationRequest
     *
     * @returns Deserialized RelayedAuthenticationRequest object.
     */
    getRelayedAuthenticationRequest(): acsWebhooks.RelayedAuthenticationRequest;
}
