import { AccountHolderCapability } from "./accountHolderCapability";
import { ContactDetails } from "./contactDetails";
export declare class AccountHolderInfo {
    /**
    * The unique identifier of the [balance platform](https://docs.adyen.com/api-explorer/#/balanceplatform/latest/get/balancePlatforms/{id}__queryParam_id) to which the account holder belongs. Required in the request if your API credentials can be used for multiple balance platforms.
    */
    "balancePlatform"?: string;
    /**
    * Contains key-value pairs that specify the actions that an account holder can do in your platform. The key is a capability required for your integration. For example, **issueCard** for Issuing. The value is an object containing the settings for the capability.
    */
    "capabilities"?: {
        [key: string]: AccountHolderCapability;
    };
    /**
    * @deprecated
    */
    "contactDetails"?: ContactDetails | null;
    /**
    * Your description for the account holder.
    */
    "description"?: string;
    /**
    * The unique identifier of the [legal entity](https://docs.adyen.com/api-explorer/legalentity/latest/post/legalEntities#responses-200-id) associated with the account holder. Adyen performs a verification process against the legal entity of the account holder.
    */
    "legalEntityId": string;
    /**
    * A set of key and value pairs for general use. The keys do not have specific names and may be used for storing miscellaneous data as desired. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
    */
    "metadata"?: {
        [key: string]: string;
    };
    /**
    * The unique identifier of the migrated account holder in the classic integration.
    */
    "migratedAccountHolderCode"?: string;
    /**
    * Your reference for the account holder.
    */
    "reference"?: string;
    /**
    * The time zone of the account holder. For example, **Europe/Amsterdam**. Defaults to the time zone of the balance platform if no time zone is set. For possible values, see the [list of time zone codes](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
    */
    "timeZone"?: string;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
