import { BankAccountModel } from "./bankAccountModel";
import { CardInfo } from "./cardInfo";
export declare class PaymentInstrumentInfo {
    /**
    * The unique identifier of the [balance account](https://docs.adyen.com/api-explorer/#/balanceplatform/v1/post/balanceAccounts__resParam_id) associated with the payment instrument.
    */
    "balanceAccountId": string;
    "bankAccount"?: BankAccountModel | null;
    "card"?: CardInfo | null;
    /**
    * Your description for the payment instrument, maximum 300 characters.
    */
    "description"?: string;
    /**
    * The two-character [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code where the payment instrument is issued. For example, **NL** or **US**.
    */
    "issuingCountryCode": string;
    /**
    * The unique identifier of the [payment instrument group](https://docs.adyen.com/api-explorer/#/balanceplatform/v1/post/paymentInstrumentGroups__resParam_id) to which the payment instrument belongs.
    */
    "paymentInstrumentGroupId"?: string;
    /**
    * Your reference for the payment instrument, maximum 150 characters.
    */
    "reference"?: string;
    /**
    * The status of the payment instrument. If a status is not specified when creating a payment instrument, it is set to **active** by default. However, there can be exceptions for cards based on the `card.formFactor` and the `issuingCountryCode`. For example, when issuing physical cards in the US, the default status is **inactive**.  Possible values:    * **active**:  The payment instrument is active and can be used to make payments.    * **inactive**: The payment instrument is inactive and cannot be used to make payments.    * **suspended**: The payment instrument is suspended, either because it was stolen or lost.    * **closed**: The payment instrument is permanently closed. This action cannot be undone.
    */
    "status"?: PaymentInstrumentInfo.StatusEnum;
    /**
    * The status comment provides additional information for the statusReason of the payment instrument.
    */
    "statusComment"?: string;
    /**
    * The reason for the status of the payment instrument.  Possible values: **accountClosure**, **damaged**, **endOfLife**, **expired**, **lost**, **stolen**, **suspectedFraud**, **transactionRule**, **other**. If the reason is **other**, you must also send the `statusComment` parameter describing the status change.
    */
    "statusReason"?: PaymentInstrumentInfo.StatusReasonEnum;
    /**
    * The type of payment instrument.  Possible values: **card**, **bankAccount**.
    */
    "type": PaymentInstrumentInfo.TypeEnum;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace PaymentInstrumentInfo {
    enum StatusEnum {
        Active = "active",
        Closed = "closed",
        Inactive = "inactive",
        Suspended = "suspended"
    }
    enum StatusReasonEnum {
        AccountClosure = "accountClosure",
        Damaged = "damaged",
        EndOfLife = "endOfLife",
        Expired = "expired",
        Lost = "lost",
        Other = "other",
        Stolen = "stolen",
        SuspectedFraud = "suspectedFraud",
        TransactionRule = "transactionRule"
    }
    enum TypeEnum {
        BankAccount = "bankAccount",
        Card = "card"
    }
}
