import { CardInfo } from "./cardInfo";
export declare class PaymentInstrumentUpdateRequest {
    /**
    * The unique identifier of the balance account associated with this payment instrument. >You can only change the balance account ID if the payment instrument has **inactive** status.
    */
    "balanceAccountId"?: string;
    "card"?: CardInfo | null;
    /**
    * The status of the payment instrument. If a status is not specified when creating a payment instrument, it is set to **active** by default. However, there can be exceptions for cards based on the `card.formFactor` and the `issuingCountryCode`. For example, when issuing physical cards in the US, the default status is **inactive**.  Possible values:    * **active**:  The payment instrument is active and can be used to make payments.    * **inactive**: The payment instrument is inactive and cannot be used to make payments.    * **suspended**: The payment instrument is suspended, either because it was stolen or lost.    * **closed**: The payment instrument is permanently closed. This action cannot be undone.
    */
    "status"?: PaymentInstrumentUpdateRequest.StatusEnum;
    /**
    * Comment for the status of the payment instrument.  Required if `statusReason` is **other**.
    */
    "statusComment"?: string;
    /**
    * The reason for updating the status of the payment instrument.  Possible values: **lost**, **stolen**, **damaged**, **suspectedFraud**, **expired**, **endOfLife**, **accountClosure**, **other**. If the reason is **other**, you must also send the `statusComment` parameter describing the status change.
    */
    "statusReason"?: PaymentInstrumentUpdateRequest.StatusReasonEnum;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace PaymentInstrumentUpdateRequest {
    enum StatusEnum {
        Active = "active",
        Closed = "closed",
        Inactive = "inactive",
        Suspended = "suspended"
    }
    enum StatusReasonEnum {
        AccountClosure = "accountClosure",
        Damaged = "damaged",
        EndOfLife = "endOfLife",
        Expired = "expired",
        Lost = "lost",
        Other = "other",
        Stolen = "stolen",
        SuspectedFraud = "suspectedFraud",
        TransactionRule = "transactionRule"
    }
}
