import { TransferRouteRequirementsInner } from "./transferRouteRequirementsInner";
export declare class TransferRoute {
    /**
    *  The type of transfer.   Possible values:    - **bank**: Transfer to a [transfer instrument](https://docs.adyen.com/api-explorer/#/legalentity/latest/post/transferInstruments__resParam_id) or a bank account.
    */
    "category"?: TransferRoute.CategoryEnum;
    /**
    * The two-character ISO-3166-1 alpha-2 country code of the counterparty. For example, **US** or **NL**.
    */
    "country"?: string;
    /**
    * The three-character ISO currency code of transfer. For example, **USD** or **EUR**.
    */
    "currency"?: string;
    /**
    * The priority for the bank transfer. This sets the speed at which the transfer is sent and the fees that you have to pay. Possible values:  * **regular**: for normal, low-value transactions.  * **fast**: a faster way to transfer funds, but the fees are higher. Recommended for high-priority, low-value transactions.  * **wire**: the fastest way to transfer funds, but this has the highest fees. Recommended for high-priority, high-value transactions.  * **instant**: for instant funds transfers within the United States and in [SEPA locations](https://www.ecb.europa.eu/paym/integration/retail/sepa/html/index.en.html).  * **crossBorder**: for high-value transfers to a recipient in a different country.  * **internal**: for transfers to an Adyen-issued business bank account (by bank account number/IBAN).
    */
    "priority"?: TransferRoute.PriorityEnum;
    /**
    * A set of rules defined by clearing houses and banking partners. Your transfer request must adhere to these rules to ensure successful initiation of transfer. Based on the priority, one or more requirements may be returned. Each requirement is defined with a `type` and `description`.
    */
    "requirements"?: Array<TransferRouteRequirementsInner>;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace TransferRoute {
    enum CategoryEnum {
        Bank = "bank",
        Card = "card",
        Grants = "grants",
        Interest = "interest",
        Internal = "internal",
        IssuedCard = "issuedCard",
        Migration = "migration",
        PlatformPayment = "platformPayment",
        TopUp = "topUp",
        Upgrade = "upgrade"
    }
    enum PriorityEnum {
        CrossBorder = "crossBorder",
        Fast = "fast",
        Instant = "instant",
        Internal = "internal",
        Regular = "regular",
        Wire = "wire"
    }
}
