import { Counterparty } from "./counterparty";
export declare class TransferRouteRequest {
    /**
    * The unique identifier of the source [balance account](https://docs.adyen.com/api-explorer/#/balanceplatform/latest/post/balanceAccounts__resParam_id). Required if `counterparty` is **transferInstrumentId**.
    */
    "balanceAccountId"?: string;
    /**
    * The unique identifier assigned to the balance platform associated with the account holder.
    */
    "balancePlatform": string;
    /**
    *  The type of transfer. Possible values:    - **bank**: Transfer to a [transfer instrument](https://docs.adyen.com/api-explorer/#/legalentity/latest/post/transferInstruments__resParam_id) or a bank account.
    */
    "category": TransferRouteRequest.CategoryEnum;
    "counterparty"?: Counterparty | null;
    /**
    * The two-character ISO-3166-1 alpha-2 country code of the counterparty. For example, **US** or **NL**.  > Either `counterparty` or `country` field must be provided in a transfer route request.
    */
    "country"?: string;
    /**
    * The three-character ISO currency code of transfer. For example, **USD** or **EUR**.
    */
    "currency": string;
    /**
    * The list of priorities for the bank transfer. Priorities set the speed at which the transfer is sent and the fees that you have to pay. Multiple values can be provided. Possible values:  * **regular**: for normal, low-value transactions.  * **fast**: a faster way to transfer funds, but the fees are higher. Recommended for high-priority, low-value transactions.  * **wire**: the fastest way to transfer funds, but this has the highest fees. Recommended for high-priority, high-value transactions.  * **instant**: for instant funds transfers within the United States and in [SEPA locations](https://www.ecb.europa.eu/paym/integration/retail/sepa/html/index.en.html).  * **crossBorder**: for high-value transfers to a recipient in a different country.  * **internal**: for transfers to an Adyen-issued business bank account (by bank account number/IBAN).
    */
    "priorities"?: Array<TransferRouteRequest.PrioritiesEnum>;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace TransferRouteRequest {
    enum CategoryEnum {
        Bank = "bank"
    }
    enum PrioritiesEnum {
        CrossBorder = "crossBorder",
        Fast = "fast",
        Instant = "instant",
        Internal = "internal",
        Regular = "regular",
        Wire = "wire"
    }
}
