export declare class ThreeDS2Result {
    /**
    * The `authenticationValue` value as defined in the 3D Secure 2 specification.
    */
    "authenticationValue"?: string;
    /**
    * The algorithm used by the ACS to calculate the authentication value, only for Cartes Bancaires integrations.
    */
    "cavvAlgorithm"?: string;
    /**
    * Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to [3D Secure API reference](https://docs.adyen.com/online-payments/3d-secure/api-reference#mpidata).
    */
    "challengeCancel"?: ThreeDS2Result.ChallengeCancelEnum;
    /**
    * The `dsTransID` value as defined in the 3D Secure 2 specification.
    */
    "dsTransID"?: string;
    /**
    * The `eci` value as defined in the 3D Secure 2 specification.
    */
    "eci"?: string;
    /**
    * Indicates the exemption type that was applied by the issuer to the authentication, if exemption applied. Allowed values: * `lowValue` * `secureCorporate` * `trustedBeneficiary` * `transactionRiskAnalysis`
    */
    "exemptionIndicator"?: ThreeDS2Result.ExemptionIndicatorEnum;
    /**
    * The `messageVersion` value as defined in the 3D Secure 2 specification.
    */
    "messageVersion"?: string;
    /**
    * Risk score calculated by Cartes Bancaires Directory Server (DS).
    */
    "riskScore"?: string;
    /**
    * Indicates whether a challenge is requested for this transaction. Possible values: * **01** — No preference * **02** — No challenge requested * **03** — Challenge requested (3DS Requestor preference) * **04** — Challenge requested (Mandate) * **05** — No challenge (transactional risk analysis is already performed) * **06** — Data Only
    */
    "threeDSRequestorChallengeInd"?: ThreeDS2Result.ThreeDSRequestorChallengeIndEnum;
    /**
    * The `threeDSServerTransID` value as defined in the 3D Secure 2 specification.
    */
    "threeDSServerTransID"?: string;
    /**
    * The `timestamp` value of the 3D Secure 2 authentication.
    */
    "timestamp"?: string;
    /**
    * The `transStatus` value as defined in the 3D Secure 2 specification.
    */
    "transStatus"?: string;
    /**
    * Provides information on why the `transStatus` field has the specified value. For possible values, refer to [our docs](https://docs.adyen.com/online-payments/3d-secure/api-reference#possible-transstatusreason-values).
    */
    "transStatusReason"?: string;
    /**
    * The `whiteListStatus` value as defined in the 3D Secure 2 specification.
    */
    "whiteListStatus"?: string;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace ThreeDS2Result {
    enum ChallengeCancelEnum {
        _01 = "01",
        _02 = "02",
        _03 = "03",
        _04 = "04",
        _05 = "05",
        _06 = "06",
        _07 = "07"
    }
    enum ExemptionIndicatorEnum {
        LowValue = "lowValue",
        SecureCorporate = "secureCorporate",
        TrustedBeneficiary = "trustedBeneficiary",
        TransactionRiskAnalysis = "transactionRiskAnalysis"
    }
    enum ThreeDSRequestorChallengeIndEnum {
        _01 = "01",
        _02 = "02",
        _03 = "03",
        _04 = "04",
        _05 = "05",
        _06 = "06"
    }
}
