export declare class OnboardingLinkSettings {
    /**
    * The list of countries the user can choose from in hosted onboarding when `editPrefilledCountry` is allowed.  The value must be in the two-character [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code format.  The array is empty by default, allowing all [countries and regions supported by hosted onboarding](https://docs.adyen.com/platforms/onboard-users/#hosted-onboarding).
    */
    "acceptedCountries"?: Array<string>;
    /**
    * Default value: **false**  Indicates if the user can select the format for their payout account (if applicable).
    */
    "allowBankAccountFormatSelection"?: boolean;
    /**
    * Default value: **true**  Indicates whether the debug user interface (UI) is enabled. The debug UI provides information for your support staff to diagnose and resolve user issues during onboarding. It can be accessed using a keyboard shortcut.
    */
    "allowDebugUi"?: boolean;
    /**
    * Default value: **false**  Indicates if the user can select a payout account in a different EU/EEA location (including Switzerland and the UK) than the location of their legal entity.
    */
    "allowIntraRegionCrossBorderPayout"?: boolean;
    /**
    * Default value: **true**  Indicates if the user can change their legal entity type.
    */
    "changeLegalEntityType"?: boolean;
    /**
    * Default value: **true**  Indicates if the user can change the country of their legal entity\'s address, for example the registered address of an organization.
    */
    "editPrefilledCountry"?: boolean;
    /**
    * Default value: **false**  Indicates if only users above the age of 18 can be onboarded.
    */
    "enforceLegalAge"?: boolean;
    /**
    * Default value: **true**  Indicates whether the introduction screen is hidden for the user of the individual legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
    */
    "hideOnboardingIntroductionIndividual"?: boolean;
    /**
    * Default value: **true**  Indicates whether the introduction screen is hidden for the user of the organization legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
    */
    "hideOnboardingIntroductionOrganization"?: boolean;
    /**
    * Default value: **true**  Indicates whether the introduction screen is hidden for the user of the sole proprietorship legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
    */
    "hideOnboardingIntroductionSoleProprietor"?: boolean;
    /**
    * Default value: **true**  Indicates whether the introduction screen is hidden for the user of the trust legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
    */
    "hideOnboardingIntroductionTrust"?: boolean;
    /**
    * Default value: **true**  Indicates if the user can initiate the verification process through open banking providers, like Plaid or Tink.
    */
    "instantBankVerification"?: boolean;
    /**
    * Default value: **false**  Indicates if the user is required to sign a PCI questionnaires for the **ecomMoto** sales channel type.
    */
    "requirePciSignEcomMoto"?: boolean;
    /**
    * Default value: **false**  Indicates if the user is required to sign a PCI questionnaires for the **eCommerce** sales channel type.
    */
    "requirePciSignEcommerce"?: boolean;
    /**
    * Default value: **false**  Indicates if the user is required to sign a PCI questionnaires for the **pos** sales channel type.
    */
    "requirePciSignPos"?: boolean;
    /**
    * Default value: **false**  Indicates if the user is required to sign a PCI questionnaires for the **posMoto** sales channel type.
    */
    "requirePciSignPosMoto"?: boolean;
    /**
    * The maximum number of transfer instruments the user can create.
    */
    "transferInstrumentLimit"?: number;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
