import { Address } from "./address";
import { FinancialReport } from "./financialReport";
import { PhoneNumber } from "./phoneNumber";
import { StockData } from "./stockData";
import { TaxInformation } from "./taxInformation";
import { TaxReportingClassification } from "./taxReportingClassification";
import { WebData } from "./webData";
export declare class Organization {
    /**
    * The two-character [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code of the governing country.
    */
    "countryOfGoverningLaw"?: string;
    /**
    * The date when the organization was incorporated in YYYY-MM-DD format.
    */
    "dateOfIncorporation"?: string;
    /**
    * Your description for the organization.
    */
    "description"?: string;
    /**
    * The organization\'s trading name, if different from the registered legal name.
    */
    "doingBusinessAs"?: string;
    /**
    * The email address of the legal entity.
    */
    "email"?: string;
    /**
    * The financial report information of the organization.
    */
    "financialReports"?: Array<FinancialReport>;
    /**
    * The organization\'s legal name.
    */
    "legalName": string;
    "phone"?: PhoneNumber | null;
    "principalPlaceOfBusiness"?: Address | null;
    "registeredAddress": Address;
    /**
    * The organization\'s registration number.
    */
    "registrationNumber"?: string;
    "stockData"?: StockData | null;
    /**
    * The tax information of the organization.
    */
    "taxInformation"?: Array<TaxInformation>;
    "taxReportingClassification"?: TaxReportingClassification | null;
    /**
    * Type of organization.  Possible values: **associationIncorporated**, **governmentalOrganization**, **listedPublicCompany**, **nonProfit**, **partnershipIncorporated**, **privateCompany**.
    */
    "type"?: Organization.TypeEnum;
    /**
    * The reason the organization has not provided a VAT number.  Possible values: **industryExemption**, **belowTaxThreshold**.
    */
    "vatAbsenceReason"?: Organization.VatAbsenceReasonEnum;
    /**
    * The organization\'s VAT number.
    */
    "vatNumber"?: string;
    "webData"?: WebData | null;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace Organization {
    enum TypeEnum {
        AssociationIncorporated = "associationIncorporated",
        GovernmentalOrganization = "governmentalOrganization",
        ListedPublicCompany = "listedPublicCompany",
        NonProfit = "nonProfit",
        PartnershipIncorporated = "partnershipIncorporated",
        PrivateCompany = "privateCompany"
    }
    enum VatAbsenceReasonEnum {
        IndustryExemption = "industryExemption",
        BelowTaxThreshold = "belowTaxThreshold"
    }
}
