import { Address } from "./address";
import { FinancialReport } from "./financialReport";
import { TaxInformation } from "./taxInformation";
export declare class SoleProprietorship {
    /**
    * The two-character [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code of the governing country.
    */
    "countryOfGoverningLaw": string;
    /**
    * The date when the legal arrangement was incorporated in YYYY-MM-DD format.
    */
    "dateOfIncorporation"?: string;
    /**
    * The registered name, if different from the `name`.
    */
    "doingBusinessAs"?: string;
    /**
    * The information from the financial report of the sole proprietorship.
    */
    "financialReports"?: Array<FinancialReport>;
    /**
    * The legal name.
    */
    "name": string;
    "principalPlaceOfBusiness"?: Address | null;
    "registeredAddress": Address;
    /**
    * The registration number.
    */
    "registrationNumber"?: string;
    /**
    * The tax information is absent.
    */
    "taxAbsent"?: boolean | null;
    /**
    * The tax information of the entity.
    */
    "taxInformation"?: Array<TaxInformation>;
    /**
    * The reason for not providing a VAT number.  Possible values: **industryExemption**, **belowTaxThreshold**.
    */
    "vatAbsenceReason"?: SoleProprietorship.VatAbsenceReasonEnum;
    /**
    * The VAT number.
    */
    "vatNumber"?: string;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace SoleProprietorship {
    enum VatAbsenceReasonEnum {
        IndustryExemption = "industryExemption",
        BelowTaxThreshold = "belowTaxThreshold"
    }
}
