import { AndroidAppError } from "./androidAppError";
export declare class AndroidApp {
    /**
    * The description that was provided when uploading the app. The description is not shown on the terminal.
    */
    "description"?: string;
    /**
    * The error code of the Android app with the `status` of either **error** or **invalid**.
    *
    * @deprecated since Management API v3
    * Use `errors` instead.
    */
    "errorCode"?: string;
    /**
    * The list of errors of the Android app.
    */
    "errors"?: Array<AndroidAppError>;
    /**
    * The unique identifier of the app.
    */
    "id": string;
    /**
    * The app name that is shown on the terminal.
    */
    "label"?: string;
    /**
    * The package name that uniquely identifies the Android app.
    */
    "packageName"?: string;
    /**
    * The status of the app. Possible values:  * `processing`: the app is being signed and converted to a format that the terminal can handle. * `error`: something went wrong. Check that the app matches the [requirements](https://docs.adyen.com/point-of-sale/android-terminals/app-requirements). * `invalid`: there is something wrong with the APK file of the app. * `ready`: the app has been signed and converted. * `archived`: the app is no longer available.
    */
    "status": AndroidApp.StatusEnum;
    /**
    * The version number of the app.
    */
    "versionCode"?: number;
    /**
    * The app version number that is shown on the terminal.
    */
    "versionName"?: string;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace AndroidApp {
    enum StatusEnum {
        Archived = "archived",
        Error = "error",
        Invalid = "invalid",
        Processing = "processing",
        Ready = "ready"
    }
}
