import { SplitConfigurationLogic } from "./splitConfigurationLogic";
export declare class SplitConfigurationRule {
    /**
    * The currency condition that defines whether the split logic applies. Its value must be a three-character [ISO currency code](https://en.wikipedia.org/wiki/ISO_4217).
    */
    "currency": string;
    /**
    * The funding source of the payment method. This only applies to card transactions.  Possible values: * **credit** * **debit** * **prepaid** * **deferred_debit** * **charged** * **ANY**
    */
    "fundingSource"?: SplitConfigurationRule.FundingSourceEnum;
    /**
    * The payment method condition that defines whether the split logic applies.  Possible values: * [Payment method variant](https://docs.adyen.com/development-resources/paymentmethodvariant): Apply the split logic for a specific payment method. * **ANY**: Apply the split logic for all available payment methods.
    */
    "paymentMethod": string;
    /**
    * The unique identifier of the split configuration rule.
    */
    "ruleId"?: string;
    /**
    * The sales channel condition that defines whether the split logic applies.  Possible values: * **Ecommerce**: Online transactions where the cardholder is present. * **ContAuth**: Card on file and/or subscription transactions, where the cardholder is known to the merchant (returning customer). * **Moto**: Mail-order and telephone-order transactions where the customer is in contact with the merchant via email or telephone. * **POS**: Point-of-sale transactions where the customer is physically present to make a payment using a secure payment terminal. * **ANY**: All sales channels.
    */
    "shopperInteraction": SplitConfigurationRule.ShopperInteractionEnum;
    "splitLogic": SplitConfigurationLogic;
    static readonly discriminator: string | undefined;
    static readonly mapping: {
        [index: string]: string;
    } | undefined;
    static readonly attributeTypeMap: Array<{
        name: string;
        baseName: string;
        type: string;
        format: string;
    }>;
    static getAttributeTypeMap(): {
        name: string;
        baseName: string;
        type: string;
        format: string;
    }[];
    constructor();
}
export declare namespace SplitConfigurationRule {
    enum FundingSourceEnum {
        Charged = "charged",
        Credit = "credit",
        Debit = "debit",
        DeferredDebit = "deferred_debit",
        Prepaid = "prepaid",
        Any = "ANY"
    }
    enum ShopperInteractionEnum {
        Ecommerce = "Ecommerce",
        ContAuth = "ContAuth",
        Moto = "Moto",
        Pos = "POS",
        Any = "ANY"
    }
}
