import { reportWebhooks } from "..";
/**
 * Union type for all supported webhook requests.
 * Allows generic handling of configuration-related webhook events.
 */
export type GenericWebhook = reportWebhooks.ReportNotificationRequest;
/**
 * Handler for processing ReportWebhooks.
 *
 * This class provides functionality to deserialize the payload of ReportWebhooks events.
 */
export declare class ReportWebhooksHandler {
    private readonly payload;
    constructor(jsonPayload: string);
    /**
     * This method checks the type of the webhook payload and returns the appropriate deserialized object.
     *
     * @returns A deserialized object of type GenericWebhook.
     * @throws Error if the type is not recognized.
     */
    getGenericWebhook(): GenericWebhook;
    /**
     * Deserialize the webhook payload into a ReportNotificationRequest
     *
     * @returns Deserialized ReportNotificationRequest object.
     */
    getReportNotificationRequest(): reportWebhooks.ReportNotificationRequest;
}
