import { transactionWebhooks } from "..";
/**
 * Union type for all supported webhook requests.
 * Allows generic handling of configuration-related webhook events.
 */
export type GenericWebhook = transactionWebhooks.TransactionNotificationRequestV4;
/**
 * Handler for processing TransactionWebhooks.
 *
 * This class provides functionality to deserialize the payload of TransactionWebhooks events.
 */
export declare class TransactionWebhooksHandler {
    private readonly payload;
    constructor(jsonPayload: string);
    /**
     * This method checks the type of the webhook payload and returns the appropriate deserialized object.
     *
     * @returns A deserialized object of type GenericWebhook.
     * @throws Error if the type is not recognized.
     */
    getGenericWebhook(): GenericWebhook;
    /**
     * Deserialize the webhook payload into a TransactionNotificationRequestV4
     *
     * @returns Deserialized TransactionNotificationRequestV4 object.
     */
    getTransactionNotificationRequestV4(): transactionWebhooks.TransactionNotificationRequestV4;
}
