import { transferWebhooks } from "..";
/**
 * Union type for all supported webhook requests.
 * Allows generic handling of configuration-related webhook events.
 */
export type GenericWebhook = transferWebhooks.TransferNotificationRequest;
/**
 * Handler for processing TransferWebhooks.
 *
 * This class provides functionality to deserialize the payload of TransferWebhooks events.
 */
export declare class TransferWebhooksHandler {
    private readonly payload;
    constructor(jsonPayload: string);
    /**
     * This method checks the type of the webhook payload and returns the appropriate deserialized object.
     *
     * @returns A deserialized object of type GenericWebhook.
     * @throws Error if the type is not recognized.
     */
    getGenericWebhook(): GenericWebhook;
    /**
     * Deserialize the webhook payload into a TransferNotificationRequest
     *
     * @returns Deserialized TransferNotificationRequest object.
     */
    getTransferNotificationRequest(): transferWebhooks.TransferNotificationRequest;
}
